/**
 * @Element.java 14.10.2010 Copyright 2010 - 2017 javabeginners.de. All rights
 *               reserved
 * @author J&ouml;rg Czeschla
 *
 *         This file is a part of Sudoku Sudoku is free software; you can
 *         redistribute it and/or modify it under the terms of the GNU General
 *         Public License as published by the Free Software Foundation; either
 *         version 2 of the License, or (at your option) any later version.
 * 
 *         Sudoku is distributed in the hope that it will be useful, but WITHOUT
 *         ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 *         FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *         for more details.
 * 
 *         You should have received a copy of the GNU General Public License
 *         along with Spiele; if not, write to the Free Software Foundation,
 *         Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.yourwebs.sudoku;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JTextField;
import javax.swing.SwingConstants;
import javax.swing.border.LineBorder;

public class Element extends JTextField implements MouseListener {

    /**
     * Quadrat-Index dieses Elementes
     */
    private int quad;

    /**
     * Reihen-Index dieses Elementes
     */
    private int row;

    /**
     * Spalten-Index dieses Elementes
     */
    private int col;

    /**
     * Faktor zur Skalierung der Schrift
     */
    private int faktor, weight = SudokuConstants.FONT_WEIGHT;

    private boolean speak = false;

    private SudokuGUI parent;

    private Color fgColor = Color.BLACK;

    private Color borderColor = Color.BLACK;

    private Font font;

    private LineBorder border;

    public Element(SudokuGUI parent, int faktor, int fontWeight) {
        this.parent = parent;
        this.faktor = faktor;
        this.weight = fontWeight;
        this.font = new Font(SudokuConstants.FONT_FACE, weight, this.faktor);
        this.border = new LineBorder(borderColor, faktor / 16);
        this.setHorizontalAlignment(SwingConstants.CENTER);
        this.addMouseListener(this);
        this.setHighlighter(null);
    }

    @Override
    public void paintComponent(Graphics g) {
        super.paintComponent(g);
        setFont(font);
        setBorder(border);
        setCaretColor(fgColor);
    }

    @Override
    public void setForeground(Color c) {
        super.setForeground(c);
        fgColor = c;
    }

    public void setFontWeight(int weight) {
        this.weight = weight;
        this.repaint();
    }
    
    public void reloadFont() {
        font = new Font(SudokuConstants.FONT_FACE, weight, this.faktor);
        this.setFont(font);
        this.repaint();
    }

    public int getQuad() {
        return quad;
    }

    public void setQuad(int quad) {
        this.quad = quad;
    }

    public int getRow() {
        return row;
    }

    public void setRow(int row) {
        this.row = row;
    }

    public int getCol() {
        return col;
    }

    public void setCol(int col) {
        this.col = col;
    }

    public void setFaktor(int faktor) {
        this.faktor = faktor;
    }

    public void setFGColor(Color color) {
        fgColor = color;
        repaint();
    }

    public void setBorderColor(Color color) {
        borderColor = color;
        border = new LineBorder(borderColor, faktor / 16);
        repaint();
    }

    @Override
    public void mouseClicked(MouseEvent e) {
    }

    @Override
    public void mousePressed(MouseEvent e) {
    }

    @Override
    public void mouseReleased(MouseEvent e) {
        parent.highlightNumber(this.getText());
    }

    @Override
    public void mouseEntered(MouseEvent e) {
        if (parent.getSpeechPlayable() && speak) {
            String s = getText();
            if (s != "" && s != null) {
                parent.playSound(Config.SOUND_PATH.value + s + ".wav");
            }
        }
    }

    @Override
    public void mouseExited(MouseEvent e) {
    }
}
