/**
 * @OptionDialog.java     20.11.2010
 * Copyright 2010 - 2013 javabeginners.de. All rights reserved
 * @author J&ouml;rg Czeschla
 *
 * Einstellungs-Dialog des Sudokus
 *
 * This file is a part of Sudoku
 * Sudoku is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * Sudoku is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License along with Sudoku;
 * if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA. 
 */
package de.yourwebs.sudoku;

import java.awt.Component;
import java.awt.Container;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.text.NumberFormat;

import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JFormattedTextField;
import javax.swing.JLabel;
import javax.swing.JSlider;
import javax.swing.event.CaretEvent;
import javax.swing.event.CaretListener;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.text.NumberFormatter;

public class OptionDialog extends JDialog implements ChangeListener, CaretListener {

	JSlider slider;
	JCheckBox fettBox, accessBox, mistakeBox, successSoundBox, speechBox;
	JFormattedTextField delayTextField;
	SudokuGUI parent;

	public OptionDialog(SudokuGUI parent) {
		this.parent = parent;

		GridBagLayout gridbag = new GridBagLayout();
		GridBagConstraints c = new GridBagConstraints();
		c.anchor = GridBagConstraints.WEST;
		c.insets = new Insets(5, 5, 5, 5);

		this.setLayout(gridbag);

		JLabel sizeLabel = new JLabel("Gr\u00F6\u00DFe:");

		JLabel fettLabel = new JLabel("Fettschrift:");
		int f = parent.getFaktor();
		f = f >= 150 ? f : 150;
		f = f <= 500 ? f : 500;
		slider = new JSlider(150, 500, f);
		slider.addChangeListener(this);

		fettBox = new JCheckBox();
		fettBox.setSelected(parent.getFontWeight() == 1 ? true : false);
		fettBox.addChangeListener(this);

		JLabel accessLabel = new JLabel("Kontrast:");

		accessBox = new JCheckBox();
		accessBox.setSelected(parent.getContrast());
		accessBox.addChangeListener(this);
		
		JLabel mistakeLabel = new JLabel("Fehlerhinweis");
		
		mistakeBox = new JCheckBox();
		mistakeBox.setSelected(parent.getMistakeHint());
		mistakeBox.addChangeListener(this);
		
		JLabel successSoundLabel = new JLabel("Akustische Erfolgsmeldung");
		
		successSoundBox = new JCheckBox();
		successSoundBox.setSelected(parent.getSuccessSoundPlayable());
		successSoundBox.addChangeListener(this);
		
		JLabel speechLabel = new JLabel("Sprachausgabe");
		
		speechBox = new JCheckBox();
		speechBox.setSelected(parent.getSpeechPlayable());
		speechBox.addChangeListener(this);
		
		JLabel delayLabel = new JLabel("Dauer Fehleranzeige [ms]");
		// nur ganzzahlige Werte zulassen
		NumberFormat format = NumberFormat.getIntegerInstance();
		// Tausendertrenner verhindern
		format.setGroupingUsed(false);
		delayTextField = new JFormattedTextField(format);
		// Falscheingabe verhindern
        ((NumberFormatter)delayTextField.getFormatter()).setAllowsInvalid(false);
        delayTextField.setColumns(5);
		delayTextField.setText(parent.getMistakeDelay());
		delayTextField.addCaretListener(this);

		this.add(sizeLabel, c, 0, 0, 1, 1, this);
		this.add(slider, c, 1, 0, 1, 1, this);
		this.add(fettLabel, c, 0, 1, 1, 1, this);
		this.add(fettBox, c, 1, 1, 1, 1, this);
		this.add(accessLabel, c, 0, 2, 1, 1, this);
		this.add(accessBox, c, 1, 2, 1, 1, this);
		this.add(mistakeLabel, c, 0, 3, 1, 1, this);
		this.add(mistakeBox, c, 1, 3, 1, 1, this);
		this.add(successSoundLabel, c, 0, 4, 1, 1, this);
		this.add(successSoundBox, c, 1, 4, 1, 1, this);
		this.add(speechLabel, c, 0, 5, 1, 1, this);
		this.add(speechBox, c, 1, 5, 1, 1, this);
		this.add(delayLabel, c, 0, 6, 1, 1, this);
		this.add(delayTextField, c, 1, 6, 1, 1, this);

		this.setLocationRelativeTo(parent);
		this.setTitle("Einstellungen");
		this.pack();
		setVisible(true);
	}

	public void add(Component c, GridBagConstraints constraints, int x, int y,
			int w, int h, Container p) {
		constraints.gridx = x;
		constraints.gridy = y;
		constraints.gridwidth = w;
		constraints.gridheight = h;
		p.add(c, constraints);
	}

	@Override
	public void stateChanged(ChangeEvent arg0) {
		if (arg0.getSource() == slider) {
			parent.setFaktor(slider.getValue());
		}

		if (arg0.getSource() == fettBox) {
			parent.setFontWeight(((JCheckBox) arg0.getSource()).isSelected());
		}

		if (arg0.getSource() == accessBox) {
			parent.setContrast(((JCheckBox) arg0.getSource())
					.isSelected());
		}
		
		if(arg0.getSource() == mistakeBox) {
		    parent.setMistakeHint(((JCheckBox) arg0.getSource())
                    .isSelected());
		}
		
		if (arg0.getSource() == successSoundBox) {
			parent.setSuccessSoundPlayable(((JCheckBox) arg0.getSource())
					.isSelected());
		}
		
		if (arg0.getSource() == speechBox) {
			parent.setSpeechPlayable(((JCheckBox) arg0.getSource())
					.isSelected());
		}
	}

	/* (non-Javadoc)
	 * @see javax.swing.event.CaretListener#caretUpdate(javax.swing.event.CaretEvent)
	 */
	@Override
	public void caretUpdate(CaretEvent ce) {
		if(ce.getSource() == delayTextField)
		parent.setMistakeDelay(delayTextField.getText());
	}
}
