/**
 * @StatusBar.java 20.10.2010 Copyright 2010 - 2017 yourwebs.de. All rights
 *                 reserved
 * @author J&ouml;rg Czeschla
 *
 *         This file is a part of Sudoku Sudoku is free software; you can
 *         redistribute it and/or modify it under the terms of the GNU General
 *         Public License as published by the Free Software Foundation; either
 *         version 2 of the License, or (at your option) any later version.
 * 
 *         Sudoku is distributed in the hope that it will be useful, but WITHOUT
 *         ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 *         FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *         for more details.
 * 
 *         You should have received a copy of the GNU General Public License
 *         along with Spiele; if not, write to the Free Software Foundation,
 *         Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.yourwebs.sudoku;

import java.awt.FlowLayout;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSeparator;
import javax.swing.JSlider;
import javax.swing.SwingConstants;
import javax.swing.border.EmptyBorder;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

public class StatusBar extends JPanel implements ChangeListener {

    SudokuGUI parent;
    JLabel cellLabel, mistakeLabel;
    JSlider slider;

    public StatusBar(final SudokuGUI parent, int initialSliderPosition) {
        this.parent = parent;
        this.setBorder(new EmptyBorder(0, 10, 0, 10));
        createStatusElements(initialSliderPosition);
    }

    /**
     * Create the gui elements of the status bar
     * 
     * @param initialSliderPosition
     *            <code>int</code> initial position of the slider defining the
     *            game's difficulty.
     */
    private void createStatusElements(int initialSliderPosition) {
        // Cells
        cellLabel = new JLabel();
        // Mistakes
        mistakeLabel = new JLabel();
        // Slider
        JPanel sliderPanel = new JPanel(
                new FlowLayout(FlowLayout.LEADING, 0, 0));
        slider = new JSlider(20, 60, initialSliderPosition);
        slider.addChangeListener(this);
        slider.addMouseListener(new MouseAdapter() {
            @Override
            public void mouseReleased(MouseEvent e) {
                parent.initNewSudoku();
            }
        });
        this.setLayout(new FlowLayout(SwingConstants.LEADING));
        this.add(cellLabel);
        this.add(new JSeparator(SwingConstants.VERTICAL));
        this.add(mistakeLabel);
        this.add(new JSeparator(SwingConstants.VERTICAL));
        sliderPanel.add(new JLabel("+"));
        sliderPanel.add(slider);
        sliderPanel.add(new JLabel("-"));
        this.add(sliderPanel);
    }

    public void setEmptyCells(int emptyCells) {
        int fs = parent.getFieldSize();
        String s = new Integer(fs * fs).toString();
        cellLabel.setText("ausgef\u00FCllt: "
                + new Integer(emptyCells).toString() + "|" + s);
    }

    public void setMistakeCount(int mistakes) {
        mistakeLabel.setText("Fehler: " + new Integer(mistakes).toString());
    }

    public void setTime(String s) {
        cellLabel.setText(s);
    }

    @Override
    public void stateChanged(ChangeEvent arg0) {
        parent.setDifficulty(slider.getValue());
    }
}
