/**
 * @SudokuMenu.java     20.11.2010
 * build: 20.11.2010
 * Copyright 2010 - 2013 yourwebs.de. All rights reserved
 * @author J&ouml;rg Czeschla
 *
 * This file is a part of Sudoku
 * Sudoku is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * Sudoku is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License along with Sudoku;
 * if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA. 
 */
package de.yourwebs.sudoku;

import java.awt.Event;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;

/**
 *
 * 
 */
public class SudokuMenu extends JMenuBar implements ActionListener {

	private JMenuItem openItem, saveItem, exitItem, newItem, printItem,
			completeItem, optionsItem, aboutItem;
	
	SudokuGUI parent;
	
	SudokuEngine engine;
	
	public SudokuMenu(SudokuGUI parent){
		this.parent = parent;
		this.engine = parent.getEngine();
		init();
	}
	
	/**
	 * Konfiguration der MenuItems
	 */
	private void init() {
		// Datei-Menu
		JMenu dateiMenu = new JMenu("Datei");
		add(dateiMenu);

		openItem = new JMenuItem("Laden");
		openItem.addActionListener(this);
		openItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_O,
				Event.CTRL_MASK));
		saveItem = new JMenuItem("Speichern");
		saveItem.addActionListener(this);
		saveItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_S,
				Event.CTRL_MASK));
		exitItem = new JMenuItem("Schlie\u00DFen");
		exitItem.addActionListener(this);
		exitItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_Q,
				Event.CTRL_MASK));
		newItem = new JMenuItem("Neu");
		newItem.addActionListener(this);
		newItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_N,
				Event.CTRL_MASK));
		printItem = new JMenuItem("Drucken");
		printItem.addActionListener(this);
		printItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_P,
				Event.CTRL_MASK));
		completeItem = new JMenuItem("Aufl\u00F6sen");
		completeItem.addActionListener(this);
		completeItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_C,
				Event.CTRL_MASK));

		dateiMenu.add(newItem);
		dateiMenu.add(openItem);
		dateiMenu.add(completeItem);
		dateiMenu.addSeparator();
		dateiMenu.add(saveItem);
		dateiMenu.add(printItem);
		dateiMenu.addSeparator();
		dateiMenu.add(exitItem);
		
		// Extras-Menu
		JMenu extrasMenu = new JMenu("Extras");
		add(extrasMenu);
		
		optionsItem = new JMenuItem("Einstellungen");
		optionsItem.addActionListener(this);
		optionsItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_E,
				Event.CTRL_MASK));
		
		extrasMenu.add(optionsItem);
		
		// Hilfe-Menu
		JMenu helpMenu = new JMenu("Hilfe");
		add(helpMenu);
		
		aboutItem = new JMenuItem("\u00DCber " + Config.APP_NAME.value);
		aboutItem.addActionListener(this);
		aboutItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_A,
				Event.CTRL_MASK));
		
		helpMenu.add(aboutItem);
	}
	/**
	 * Eventhandling der Menuleiste
	 */
	@Override
    public void actionPerformed(ActionEvent arg0) {
		if (arg0.getSource() == openItem) {
			parent.open();
		}
		if (arg0.getSource() == saveItem) {
			parent.save();
		}
		if (arg0.getSource() == exitItem) {
			System.exit(0);
		}
		if (arg0.getSource() == newItem) {
			parent.initNewSudoku();
		}
		if (arg0.getSource() == printItem) {
			parent.print();
		}
		if (arg0.getSource() == completeItem) {
			parent.updateSudoku(engine.getResultArray());
		}
		if (arg0.getSource() == optionsItem) {
			new OptionDialog(parent);
		}
		if (arg0.getSource() == aboutItem) {
			new AboutDialog();
		}
	}
}
